candv: Constants & Values
=========================

|Build Status| |Coverage Status| |PyPi package| |Downloads|

This is a little Python library which provides an easy way for creating complex
constants. Inspired by `Constants from Twisted`_ and `Django form fields`_.

Please, `read the docs`_ for more information.

.. |Build Status| image:: https://travis-ci.org/oblalex/candv.svg?branch=master
   :target: https://travis-ci.org/oblalex/candv
.. |Coverage Status| image:: https://coveralls.io/repos/oblalex/candv/badge.png?branch=master
   :target: https://coveralls.io/r/oblalex/candv?branch=master
.. |PyPi package| image:: https://badge.fury.io/py/candv.png
   :target: http://badge.fury.io/py/candv/
.. |Downloads| image:: https://pypip.in/d/candv/badge.png
   :target: https://crate.io/packages/candv/

.. _Constants from Twisted: http://twistedmatrix.com/documents/current/core/howto/constants.html
.. _Django form fields: https://docs.djangoproject.com/en/1.6/ref/forms/fields/
.. _read the docs: http://candv.readthedocs.org/en/latest/
